#!/bin/bash -e

echo "======================= Installing gcc 10.1.0 ======================"
add-apt-repository -y ppa:ubuntu-toolchain-r/test
apt-get update
apt-get install \
  gcc-10 \
  g++-10
update-alternatives --install /usr/bin/gcc gcc /usr/bin/gcc-10 90 --slave /usr/bin/g++ g++ /usr/bin/g++-10
update-alternatives --install /usr/bin/gcov gcov /usr/bin/gcov-10 90
gcc --version
echo "================== Successfully Installed gcc 10.1.0 ==============="

echo "=================== Install packages for cpp ======================"

apt-get install && apt-get install \
  autoconf \
  automake \
  ccache \
  libssl-dev

CLANG_VERSION=10.0.0*
echo "==================== Installing clang $CLANG_VERSION ==============="
apt-get install clang-10=1:"$CLANG_VERSION"
update-alternatives --install /usr/bin/clang clang /usr/bin/clang-10 90 --slave /usr/bin/clang++ clang++ /usr/bin/clang++-10
clang --version
echo "============= Successfully Installed clang $CLANG_VERSION ==========="

echo "===================Installing Dotnet version============================="

apt-get update
apt-get install -y apt-transport-https
apt-get update

curl -SL -o dotnet.tar.gz https://dotnetcli.blob.core.windows.net/dotnet/Sdk/master/dotnet-sdk-latest-linux-arm64.tar.gz
sudo mkdir -p /usr/share/dotnet
sudo tar -zxf dotnet.tar.gz -C /usr/share/dotnet
sudo ln -s /usr/share/dotnet/dotnet /usr/bin/dotnet

echo "============= Successfully Installed dotnet version ==============="

echo "================= Install packages for Go ==================="
apt-get update && apt-get install \
	autotools-dev \
	autoconf \
	bison \
	cmake \
	scons \
	binutils \
	gcc \
	bsdmainutils \
	bzr

# Install gvm
echo "================= Install gvm ==================="
curl -s -L https://raw.githubusercontent.com/moovweb/gvm/master/binscripts/gvm-installer | bash

export CGO_ENABLED=0
#set the source path of gvm. $HOME points to '/root'
# We are getting the error while sourceing "Please restart your terminal session or to get started right away run" So we add true for souce command
[[ -s "$HOME/.gvm/scripts/gvm" ]] && source $HOME/.gvm/scripts/gvm || echo "Could not source from $HOME/.gvm/scripts/gvm"
export CGO_ENABLED=0

# Install gvm
echo "================= Install Go $GOVER ==================="
export GOROOT_BOOTSTRAP=$GOROOT
gvm install go$GOVER --prefer-binary
source /root/.gvm/scripts/gvm || echo "Could not source from /root/.gvm/scripts/gvm"
gvm use go$GOVER

echo "======= Install go linter ========="
curl -sSfL https://raw.githubusercontent.com/golangci/golangci-lint/master/install.sh | sh -s -- -b $(go env GOPATH)/bin
golangci-lint --version


echo "======================= installing java 17========================"

apt-get update
dpkg --purge --force-depends ca-certificates-java
apt-get install ca-certificates-java

GRADLE_VERSION="8.3"
echo "================ Installing gradle "$GRADLE_VERSION"  ================="
wget -nv https://services.gradle.org/distributions/gradle-$GRADLE_VERSION-all.zip
unzip -qq gradle-$GRADLE_VERSION-all.zip -d /usr/local && rm -f gradle-$GRADLE_VERSION-all.zip
ln -fs /usr/local/gradle-$GRADLE_VERSION/bin/gradle /usr/bin
echo "export PATH=$PATH:/usr/local/gradle-$GRADLE_VERSION/bin" >> /etc/drydock/.env

APACHE_MAVEN="3.9.4"
echo "================ Installing apache-maven "$APACHE_MAVEN" ================="
apt-get update
wget -nv https://dlcdn.apache.org/maven/maven-3/$APACHE_MAVEN/binaries/apache-maven-$APACHE_MAVEN-bin.tar.gz
tar xzf apache-maven-$APACHE_MAVEN-bin.tar.gz -C /usr/local && rm -f apache-maven-$APACHE_MAVEN-bin.tar.gz
ln -fs /usr/local/apache-maven-$APACHE_MAVEN/bin/mvn /usr/bin
echo "export PATH=$PATH:/usr/local/apache-maven-$APACHE_MAVEN/bin" >> /etc/drydock/.env
echo "export M2_HOME=/usr/local/apache-maven-$APACHE_MAVEN/" >> /etc/drydock/.env

APACHE_ANT="1.10.14"
echo "================ Installing apache-ant "$APACHE_ANT" ================="
apt-get update
wget -nv https://archive.apache.org/dist/ant/binaries/apache-ant-$APACHE_ANT-bin.tar.gz
tar xzf apache-ant-$APACHE_ANT-bin.tar.gz -C /usr/local && rm -f apache-ant-$APACHE_ANT-bin.tar.gz
ln -fs /usr/local/apache-ant-$APACHE_ANT/bin/ant /usr/bin
echo "export ANT_HOME=/usr/local/apache-ant-$APACHE_ANT" >> /etc/drydock/.env
echo "export PATH=$PATH:/usr/local/apache-ant-$APACHE_ANT/bin" >> /etc/drydock/.env

echo "================ Installing openjdk-"$JAVA_VERSION"-jdk ================="

if [ "$JAVA_VERSION" = "17" ]
then
  apt-get install -y openjdk-"$JAVA_VERSION"-jdk
fi

echo "=================== java 17 instalation completed============="

echo "================installing nodejs version====================="

export NVM_VERSION=v0.39.1
echo "================= Installing NVM $NVM_VERSION ================"
curl -sS https://raw.githubusercontent.com/creationix/nvm/"$NVM_VERSION"/install.sh | bash

echo "=============== Installing Node $NODE_VERSION ============="
. /root/.nvm/nvm.sh && nvm install $NODE_VERSION

